from __future__ import annotations


class ScrapyProxylandMiddleware:
    """This middleware sets the proxy value to your Proxyland package for every request processed"""
    def __init__(self, proxyland_settings) -> None:
        self.username = proxyland_settings['username']
        self.password = proxyland_settings['password']
        
    @classmethod
    def from_crawler(cls, crawler) -> ScrapyProxylandMiddleware:
        # instantiate class with PROXYLAND settings from crawler
        return cls(crawler.settings.get('PROXYLAND'))

    def process_request(self, request, spider) -> None:
        # set proxy to proxyland server 
        request.meta['proxy'] = f'http://{self.username}:{self.password}@server.proxyland.io:9090'



import pathlib
from setuptools import setup


HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name='scrapy-proxyland-middleware',
    version='1.0',
    license='MIT',
    description='Middleware to easily implement Proxyland in Scrapy projects',
    long_description_content_type='text/markdown',
    long_description=README,
    python_requires='>=3',
    project_urls={
        "Source": "https://github.com/patkle/scrapy-proxyland-middleware",
    },
    keywords='scrapy middleware proxy Proxyland',
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Topic :: Utilities'
    ],
    author='Patrick Klein',
    packages=['scrapy_proxyland_middleware'],
    install_requires=[
        'importlib-metadata ~= 1.0 ; python_version < "3.8"',
    ]
)
